[−][src]Enum unicode_types::myanmar::Myanmar
An enum to represent all characters in the Myanmar block.
Variants
LetterKa\u{1000}: 'က'
LetterKha\u{1001}: 'ခ'
LetterGa\u{1002}: 'ဂ'
LetterGha\u{1003}: 'ဃ'
LetterNga\u{1004}: 'င'
LetterCa\u{1005}: 'စ'
LetterCha\u{1006}: 'ဆ'
LetterJa\u{1007}: 'ဇ'
LetterJha\u{1008}: 'ဈ'
LetterNya\u{1009}: 'ဉ'
LetterNnya\u{100a}: 'ည'
LetterTta\u{100b}: 'ဋ'
LetterTtha\u{100c}: 'ဌ'
LetterDda\u{100d}: 'ဍ'
LetterDdha\u{100e}: 'ဎ'
LetterNna\u{100f}: 'ဏ'
LetterTa\u{1010}: 'တ'
LetterTha\u{1011}: 'ထ'
LetterDa\u{1012}: 'ဒ'
LetterDha\u{1013}: 'ဓ'
LetterNa\u{1014}: 'န'
LetterPa\u{1015}: 'ပ'
LetterPha\u{1016}: 'ဖ'
LetterBa\u{1017}: 'ဗ'
LetterBha\u{1018}: 'ဘ'
LetterMa\u{1019}: 'မ'
LetterYa\u{101a}: 'ယ'
LetterRa\u{101b}: 'ရ'
LetterLa\u{101c}: 'လ'
LetterWa\u{101d}: 'ဝ'
LetterSa\u{101e}: 'သ'
LetterHa\u{101f}: 'ဟ'
LetterLla\u{1020}: 'ဠ'
LetterA\u{1021}: 'အ'
LetterShanA\u{1022}: 'ဢ'
LetterI\u{1023}: 'ဣ'
LetterIi\u{1024}: 'ဤ'
LetterU\u{1025}: 'ဥ'
LetterUu\u{1026}: 'ဦ'
LetterE\u{1027}: 'ဧ'
LetterMonE\u{1028}: 'ဨ'
LetterO\u{1029}: 'ဩ'
LetterAu\u{102a}: 'ဪ'
VowelSignTallAa\u{102b}: 'ါ'
VowelSignAa\u{102c}: 'ာ'
VowelSignI\u{102d}: 'ိ'
VowelSignIi\u{102e}: 'ီ'
VowelSignU\u{102f}: 'ု'
VowelSignUu\u{1030}: 'ူ'
VowelSignE\u{1031}: 'ေ'
VowelSignAi\u{1032}: 'ဲ'
VowelSignMonIi\u{1033}: 'ဳ'
VowelSignMonO\u{1034}: 'ဴ'
VowelSignEAbove\u{1035}: 'ဵ'
SignAnusvara\u{1036}: 'ံ'
SignDotBelow\u{1037}: '့'
SignVisarga\u{1038}: 'း'
SignVirama\u{1039}: '္'
SignAsat\u{103a}: '်'
ConsonantSignMedialYa\u{103b}: 'ျ'
ConsonantSignMedialRa\u{103c}: 'ြ'
ConsonantSignMedialWa\u{103d}: 'ွ'
ConsonantSignMedialHa\u{103e}: 'ှ'
LetterGreatSa\u{103f}: 'ဿ'
DigitZero\u{1040}: '၀'
DigitOne\u{1041}: '၁'
DigitTwo\u{1042}: '၂'
DigitThree\u{1043}: '၃'
DigitFour\u{1044}: '၄'
DigitFive\u{1045}: '၅'
DigitSix\u{1046}: '၆'
DigitSeven\u{1047}: '၇'
DigitEight\u{1048}: '၈'
DigitNine\u{1049}: '၉'
SignLittleSection\u{104a}: '၊'
SignSection\u{104b}: '။'
SymbolLocative\u{104c}: '၌'
SymbolCompleted\u{104d}: '၍'
SymbolAforementioned\u{104e}: '၎'
SymbolGenitive\u{104f}: '၏'
LetterSha\u{1050}: 'ၐ'
LetterSsa\u{1051}: 'ၑ'
LetterVocalicR\u{1052}: 'ၒ'
LetterVocalicRr\u{1053}: 'ၓ'
LetterVocalicL\u{1054}: 'ၔ'
LetterVocalicLl\u{1055}: 'ၕ'
VowelSignVocalicR\u{1056}: 'ၖ'
VowelSignVocalicRr\u{1057}: 'ၗ'
VowelSignVocalicL\u{1058}: 'ၘ'
VowelSignVocalicLl\u{1059}: 'ၙ'
LetterMonNga\u{105a}: 'ၚ'
LetterMonJha\u{105b}: 'ၛ'
LetterMonBba\u{105c}: 'ၜ'
LetterMonBbe\u{105d}: 'ၝ'
ConsonantSignMonMedialNa\u{105e}: 'ၞ'
ConsonantSignMonMedialMa\u{105f}: 'ၟ'
ConsonantSignMonMedialLa\u{1060}: 'ၠ'
LetterSgawKarenSha\u{1061}: 'ၡ'
VowelSignSgawKarenEu\u{1062}: 'ၢ'
ToneMarkSgawKarenHathi\u{1063}: 'ၣ'
ToneMarkSgawKarenKePho\u{1064}: 'ၤ'
LetterWesternPwoKarenTha\u{1065}: 'ၥ'
LetterWesternPwoKarenPwa\u{1066}: 'ၦ'
VowelSignWesternPwoKarenEu\u{1067}: 'ၧ'
VowelSignWesternPwoKarenUe\u{1068}: 'ၨ'
SignWesternPwoKarenToneDash1\u{1069}: 'ၩ'
SignWesternPwoKarenToneDash2\u{106a}: 'ၪ'
SignWesternPwoKarenToneDash3\u{106b}: 'ၫ'
SignWesternPwoKarenToneDash4\u{106c}: 'ၬ'
SignWesternPwoKarenToneDash5\u{106d}: 'ၭ'
LetterEasternPwoKarenNna\u{106e}: 'ၮ'
LetterEasternPwoKarenYwa\u{106f}: 'ၯ'
LetterEasternPwoKarenGhwa\u{1070}: 'ၰ'
VowelSignGebaKarenI\u{1071}: 'ၱ'
VowelSignKayahOe\u{1072}: 'ၲ'
VowelSignKayahU\u{1073}: 'ၳ'
VowelSignKayahEe\u{1074}: 'ၴ'
LetterShanKa\u{1075}: 'ၵ'
LetterShanKha\u{1076}: 'ၶ'
LetterShanGa\u{1077}: 'ၷ'
LetterShanCa\u{1078}: 'ၸ'
LetterShanZa\u{1079}: 'ၹ'
LetterShanNya\u{107a}: 'ၺ'
LetterShanDa\u{107b}: 'ၻ'
LetterShanNa\u{107c}: 'ၼ'
LetterShanPha\u{107d}: 'ၽ'
LetterShanFa\u{107e}: 'ၾ'
LetterShanBa\u{107f}: 'ၿ'
LetterShanTha\u{1080}: 'ႀ'
LetterShanHa\u{1081}: 'ႁ'
ConsonantSignShanMedialWa\u{1082}: 'ႂ'
VowelSignShanAa\u{1083}: 'ႃ'
VowelSignShanE\u{1084}: 'ႄ'
VowelSignShanEAbove\u{1085}: 'ႅ'
VowelSignShanFinalY\u{1086}: 'ႆ'
SignShanToneDash2\u{1087}: 'ႇ'
SignShanToneDash3\u{1088}: 'ႈ'
SignShanToneDash5\u{1089}: 'ႉ'
SignShanToneDash6\u{108a}: 'ႊ'
SignShanCouncilToneDash2\u{108b}: 'ႋ'
SignShanCouncilToneDash3\u{108c}: 'ႌ'
SignShanCouncilEmphaticTone\u{108d}: 'ႍ'
LetterRumaiPalaungFa\u{108e}: 'ႎ'
SignRumaiPalaungToneDash5\u{108f}: 'ႏ'
ShanDigitZero\u{1090}: '႐'
ShanDigitOne\u{1091}: '႑'
ShanDigitTwo\u{1092}: '႒'
ShanDigitThree\u{1093}: '႓'
ShanDigitFour\u{1094}: '႔'
ShanDigitFive\u{1095}: '႕'
ShanDigitSix\u{1096}: '႖'
ShanDigitSeven\u{1097}: '႗'
ShanDigitEight\u{1098}: '႘'
ShanDigitNine\u{1099}: '႙'
SignKhamtiToneDash1\u{109a}: 'ႚ'
SignKhamtiToneDash3\u{109b}: 'ႛ'
VowelSignAitonA\u{109c}: 'ႜ'
VowelSignAitonAi\u{109d}: 'ႝ'
SymbolShanOne\u{109e}: '႞'
Methods
impl Myanmar[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case